<?php
// $Rev: 121 $
// $Date: 2010-07-01 10:25:01 +1000 (Thu, 01 Jul 2010) $

/**
 * @file
 * Contains theme override functions and preprocess functions for the acton theme.
 */

// Auto-rebuild the theme registry during theme development.
if (theme_get_setting('acton_rebuild_registry')) {
  drupal_rebuild_theme_registry();
}

/**
 * Implements HOOK_theme().
 */
function acton_theme(&$existing, $type, $theme, $path) {
	if (!db_is_active()) {
    return array();
  }

  // Compute the conditional stylesheets.
  if (!module_exists('conditional_styles')) {
    include_once './' . drupal_get_path('theme', 'acton') . '/template.conditional-styles.inc';
    // _conditional_styles_theme() only needs to be run once.
    if ($theme == 'acton') {
      _conditional_styles_theme($existing, $type, $theme, $path);
    }
  }

  // Since we are rebuilding the theme registry and the theme settings' default
  // values may have changed, make sure they are saved in the database properly.
	// Include the definition of acton_theme_get_default_settings().
	include_once './' . drupal_get_path('theme', 'acton') . '/template.theme-registry.inc';
  acton_theme_get_default_settings($theme);

  // If we are auto-rebuilding the theme registry, warn about the feature.
  // Always display the warning in the admin section, otherwise limit to three
  // warnings per hour.
  if (user_access('administer site configuration') && theme_get_setting('acton_rebuild_registry') && $theme == $GLOBALS['theme'] && (arg(0) == 'admin' || flood_is_allowed($GLOBALS['theme'] . '_rebuild_registry_warning', 3))) {
    flood_register_event($GLOBALS['theme'] . '_rebuild_registry_warning');
    drupal_set_message(t('For easier theme development, the theme registry is being rebuilt on every page request. It is <em>extremely</em> important to <a href="!link">turn off this feature</a> on production websites.', array('!link' => url('admin/build/themes/settings/' . $GLOBALS['theme']))), 'warning', FALSE);
  }
	
	//
	$hooks = array();

  // Return
  return $hooks;
}



/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return
 *   A string containing the breadcrumb output.
 */
function acton_breadcrumb($breadcrumb) {
	$breadcrumb_separator 	= ' &raquo; ';
	$breadcrumb_home 				= theme_get_setting('acton_breadcrumb_sitename');
	$title = menu_get_active_title();
	
  // Determine if we are to display the breadcrumb.
  $show_breadcrumb = theme_get_setting('acton_breadcrumb');
  if ($show_breadcrumb == 'yes' || $show_breadcrumb == 'admin' && arg(0) == 'admin') {
	
    // Return the breadcrumb with separators.
    if (!empty($breadcrumb)) {
			
			// check to remove duplicate items on the end
			$length = count($breadcrumb);
			if($length > 1){
				$last = end($breadcrumb);
				if(strip_tags($last) == $title) {
					array_pop($breadcrumb);
				}
			}
			// implode with separator
			$crumbs = implode($breadcrumb_separator, $breadcrumb);
      return $crumbs.$breadcrumb_separator;
    }
  }
  // Otherwise, return an empty string.
  return '';
}

/**
 * Implementation of theme_menu_local_task
 * Add the correct select element for ANU styles on active links
 */
function acton_menu_local_task($link, $active = FALSE) {
  return '<li '. ($active ? 'class="pagetabs-select" ' : '') .'>'. $link ."</li>\n";
}


/**
 * Duplicate of theme_menu_local_tasks() but adds clear-block to tabs.
 */
function acton_menu_local_tasks() {
  $output = '';
  
  //conditionally enable ctools tabs if ctools is installed
  if (module_exists('ctools')) { 
    if ($primary = ctools_menu_primary_local_tasks()) {      
      $output .= '<div class="pagetabs-nav"><ul class="local-primary clear-block">' . $primary . '</ul></div>';
    }
    if ($secondary = ctools_menu_secondary_local_tasks()) {
      $output .= '<div class="pagetabs-secondary"><ul class="local-secondary clear-block">' . $secondary . '</ul></div>';
    }
  } else { //default to the regular zen way
    if ($primary = menu_primary_local_tasks()) {
      $output .= '<div class="pagetabs-nav"><ul class="local-primary clear-block">' . $primary . '</ul></div>';
    }
    if ($secondary = menu_secondary_local_tasks()) {
      $output .= '<div class="pagetabs-secondary"><ul class="local-secondary clear-block">' . $secondary . '</ul></div>';
    }
  }

  return $output;
}
/**
 * Implementation of theme_preprocess
 */
// function acton_preprocess() {
// 
// }

/**
 * Override or insert variables into the page templates.
 *
 * @param $vars
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("page" in this case.)
 */
function acton_preprocess_page(&$vars, $hook) {
  
  // If we are on a node, load it now anyway
  // This should be cached request, and thus cheap
  if(arg(0) == 'node' && is_numeric(arg(1)) && arg(2) != 'edit'){
    $vars['node'] = node_load(arg(1));
  }
  
	// Construct page title
  if (drupal_get_title()) {
    $head_title = array(strip_tags(drupal_get_title()), variable_get('site_name', 'Drupal'));
  }
  else {
    $head_title = array(variable_get('site_name', 'Drupal'));
  }

  $vars['head_title']        = implode(' | ', $head_title);
  $vars['breadcrumb']        = theme('breadcrumb', drupal_get_breadcrumb());
  $vars['feed_icons']        = drupal_get_feeds();
  $vars['footer_message']    = '';
  $vars['logo']              = '';

  // Add conditional stylesheets.
  if (!module_exists('conditional_styles')) {
    $vars['styles'] .= $vars['conditional_styles'] = variable_get('conditional_styles_' . $GLOBALS['theme'], '');
  }

	/**
	 * ANU Styles region classes
	 * These can be overridden by sub-themes or modules
	 */
	// add basic classes for each region
	$vars['region_classes']['content_top'][] = 'region';
	$vars['region_classes']['content_top'][] = 'region-content_top';
	$vars['region_classes']['content_top'][] = 'doublewide';
	
	$vars['region_classes']['content'][] = 'region';
	$vars['region_classes']['content'][] = 'region-content';
	
	$vars['region_classes']['content_bottom'][] = 'region';
	$vars['region_classes']['content_bottom'][] = 'region-content_bottom';
	$vars['region_classes']['content_bottom'][] = 'doublewide';
	
	$vars['region_classes']['right'][] = 'region';
	$vars['region_classes']['right'][] = 'region-content_right';
	
	$vars['region_classes']['sidebar'][] = 'region';
	$vars['region_classes']['sidebar'][] = 'region-content_sidebar';
	
	// set widths based on right region
	if($vars['content'] && $vars['right']) {
		$vars['region_classes']['content'][] = 'doublenarrow';
		$vars['region_classes']['right'][] = 'narrow';
	} elseif($vars['content']) {
		$vars['region_classes']['content'][] = 'doublewide';
	}
	
	// set top padding class based on region presence
	if($vars['feature']) {
		$vars['region_classes']['feature'][] = 'doublewide';
		$vars['region_classes']['feature'][] = 'nopadtop';
	} 
	elseif($vars['content_top']){
		$vars['region_classes']['content_top'][] = 'nopadtop';
	} 
	elseif($vars['content']) {
		$vars['region_classes']['content'][] = 'nopadtop';
	}
	foreach($vars['region_classes'] as $class_name => $class_array){
		$vars['region_classes'][$class_name] = implode(' ', $class_array); // Concatenate with spaces.
	}
	
	// Add a special Drupal class for ANU themeing
	$vars['body_classes'] .= ' acton';
	
  // Classes for body element. Allows advanced theming based on context
  // (home page, node of certain type, etc.)
  $classes = explode(' ', $vars['body_classes']);
  // Remove the mostly useless page-ARG0 class.
  if ($index = array_search(preg_replace('![^abcdefghijklmnopqrstuvwxyz0-9-_]+!s', '', 'page-'. drupal_strtolower(arg(0))), $classes)) {
    unset($classes[$index]);
  }
  if (!$vars['is_front']) {
    // Add unique class for each page.
    $path = drupal_get_path_alias($_GET['q']);
    $classes[] = acton_id_safe('page-' . $path);
    // Add unique class for each website section.
    list($section, ) = explode('/', $path, 2);
    if (arg(0) == 'node') {
      if (arg(1) == 'add') {
        $section = 'node-add';
      }
      elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
        $section = 'node-' . arg(2);
      }
    }
    $classes[] = acton_id_safe('section-' . $section);
  }
  $vars['body_classes_array'] = $classes;
  $vars['body_classes'] = implode(' ', $classes); // Concatenate with spaces.
  
  // set a breadcrumb title
  $vars['breadcrumb_title'] = $vars['title'];
  
  // if we are on a Campaign node... remove the title
  if($vars['node']->type == 'acton_campaign'){
    unset($vars['title']);
  }
  
  foreach(anu_site_manager_set_head() as $k => $v) {
    $vars['html']->{'acton_' . $k} .= is_array($v) ? implode("\n", $v) : $v;
  }
}

/**
 * Override or insert variables into the node templates.
 *
 * @param $vars
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("node" in this case.)
 */
function acton_preprocess_node(&$vars, $hook) {
  // Build mode
  switch ($vars['node']->build_mode) {
    case NODE_BUILD_NORMAL:
      $vars['build_mode'] = $vars['teaser'] ? 'teaser' : 'full';
      break;
    case NODE_BUILD_PREVIEW:
      $vars['build_mode'] = 'preview';
      break;
    case NODE_BUILD_SEARCH_INDEX:
      $vars['build_mode'] = 'search_index';
      break;
    case NODE_BUILD_SEARCH_RESULT:
      $vars['build_mode'] = 'search_result';
      break;
    case NODE_BUILD_RSS:
      $vars['build_mode'] = 'rss';
      break;
    case NODE_BUILD_PRINT:
      $vars['build_mode'] = 'print';
      break;
  }
  
  $vars['display_submitted'] = theme_get_setting('toggle_node_info_' . $vars['node']->type);
  
  // Special classes for nodes
  $classes = array('node');
  if ($vars['sticky']) {
    $classes[] = 'sticky';
  }
  if (!$vars['status']) {
    $classes[] = 'node-unpublished';
    $vars['unpublished'] = TRUE;
  }
  else {
    $vars['unpublished'] = FALSE;
  }
  if ($vars['uid'] && $vars['uid'] == $GLOBALS['user']->uid) {
    $classes[] = 'node-mine'; // Node is authored by current user.
  }
  if ($vars['teaser']) {
    $classes[] = 'node-teaser'; // Node is displayed as teaser.
  }
  // Class for node type: "node-type-page", "node-type-story", "node-type-my-custom-type", etc.
  $classes[] = acton_id_safe('node-type-' . $vars['type']);
  $vars['classes'] = implode(' ', $classes); // Concatenate with spaces
  
  $vars['classes_meta'] = '';
}

/**
 * Preprocessor for theme_block().
 */
function phptemplate_preprocess_block(&$vars) {
  // If block is in a toggleable region and does not have a subject, mark it as a "widget,"
  // i.e. show its contents rather than a toggle trigger label.
  if (in_array($vars['block']->region, array('header', 'page_tools', 'space_tools'))) {
    $vars['attr']['class'] .= empty($vars['block']->subject) ? ' block-widget' : ' block-toggle';
  }
  if ($vars['block']->region === 'palette') {
    // Palette region requires module-level jQuery UI, Cookie, JSON includes.
    // Note that drupal_add_js() only works here because blocks are rendered
    // prior to the retrieval of javascript files in template_preprocess_page().
    module_exists('admin') ? drupal_add_js(drupal_get_path('module', 'admin') .'/includes/jquery.cookie.js') : '';
    module_exists('jquery_ui') ? jquery_ui_add(array('ui.draggable')) : '';
    module_exists('context_ui') ? drupal_add_js(drupal_get_path('module', 'context_ui') .'/json2.js') : '';
 
    // Add close button to palette region blocks.
    $vars['title'] = "<span class='close'></span>{$vars['title']}";
  }
  $vars['attr']['class'] .= empty($vars['block']->subject) ? ' block-notitle' : '';

}

/**
 * Override or insert variables into the block templates.
 *
 * @param $vars
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("block" in this case.)
 */
function acton_preprocess_block(&$vars, $hook) {
  $block = $vars['block'];
  $block_modes = array();
  
  // set up basic block build modes
  $block_modes['primary'] = 'menu-main';
  $block_modes['secondary'] = 'menu-grey';
  $block_modes['default'] = 'menu-grey';
  
  // set a basic $block->mode
  $block->mode = $block_modes['default'];

  // Set a block type for further processing  
  switch($block->module){
    case 'menu':
      $block->type = 'menu';
      break;
    case 'user':
      $block->type = 'user';
      break;
    case 'devel':
      $block->type = 'devel';
      break;
    default:
      $block_type = 'normal';
      break;
  }
  
  // set some blocks differently
  if($block->module == 'user' && $block->delta == '3'){
    $block->type = 'normal';
  }
  if($block->module == 'user' && $block->delta == '1'){
    $block->type = 'menu';
  }

  // Special classes for blocks.
  if(!$classes) {
		$classes = array('block');
	}	
  $classes[] = 'block-' . $block->module; 
  $classes[] = 'block-' . $block->module . '-' . $block->delta;
  $classes[] = 'region-' . $block->region;
  $classes[] = $vars['zebra'];
  $classes[] = 'count-' . $vars['id'];
  $classes[] = $block->type;

	// ANU Content Styles classes
	if(module_exists('anu_content_styles')) {
		if($vars['anu_content_styles'] && !$vars['show_box_header']){
			$vars['show_box_header'] = $vars['anu_content_styles']['show_box_header'];
			$classes = array_merge($classes, $vars['anu_content_styles']['styles']);
		}
	}

  // block edit hover links
  $vars['edit_links_array'] = array();
  $vars['edit_links'] = '';
  if (theme_get_setting('acton_block_editing') && user_access('administer blocks')) {
    include_once './' . drupal_get_path('theme', 'acton') . '/template.block-editing.inc';
    acton_preprocess_block_editing($vars, $hook);
    $classes[] = 'with-block-editing';
  }
  
  // ANU sidebar styles
  // formatting for blocks in the sidebar
  static $block_count;
  if(!isset($block_count)){
    $block_count = 1;
  }
  
  if($block->region == 'left'){
    $block->count = $block_count;
    // even though it might not be a menu, this is needed for formatting
    $classes[] = 'menu-flat'; 

    // make sure the search box and Primary links get the default colour
    if($block->module == 'search' || $block->subject == $vars['site']->metadata['site_short_name'] || $block->delta == 'primary-links') {
      $block->mode = $block_modes['primary'];
    }
    
    $menu_class = $block->mode;
    
    // If the colour has been set, use it
    $preset_colour = theme_get_setting('acton_menu_colour'); 
    if(isset($preset_colour) && $preset_colour != 'inherit' ){
      $menu_class = 'menu-'.theme_get_setting('acton_menu_colour');
    }
    
    // Finally, if we are on the main menu, overide the class
    if($block->count == 1){
      $menu_class = 'menu-main';
    }

    $classes[] = $menu_class;
    $block_count = $block_count + 1;
  }
  
  // Render block classes.
  $vars['classes'] =  $vars['block']->classes = implode(' ', $classes);
  
  // Set the title on search blocks
  if($vars['block']->module == 'search' && $vars['block']->subject == 'Search'){
    $vars['block']->subject = t('Search '.$vars['site']->metadata['site_short_name']);
  }
  // Always capitalise first word
  $vars['block']->subject = ucfirst($vars['block']->subject);
  $vars['block']->type = $block->type;
}


/**
* Override or insert PHPTemplate variables into the search_block_form template.
*
* @param $vars
*   A sequential array of variables to pass to the theme template.
* @param $hook
*   The name of the theme function being called (not used in this case.)
*/
 
function acton_preprocess_search_block_form(&$vars, $hook) {
  // Modify elements of the search form
  $vars['form']['search_block_form']['#title'] = '';
 
  // Set a default value for the search box
  $vars['form']['search_block_form']['#value'] = t('');
 
  // Add a custom class to the search box
  $vars['form']['search_block_form']['#attributes'] = array('class' => t('search-query cleardefault'));
 
  // Change the text on the submit button
  $vars['form']['submit']['#value'] = t('GO');
 
  // Rebuild the rendered version (search form only, rest remains unchanged)
  unset($vars['form']['search_block_form']['#printed']);
  $vars['search']['search_block_form'] = drupal_render($vars['form']['search_block_form']);
 
  // Rebuild the rendered version (submit button, rest remains unchanged)
  unset($vars['form']['submit']['#printed']);
  $vars['search']['submit'] = drupal_render($vars['form']['submit']);
 
  // Collect all form elements to make it easier to print the whole form.
  $vars['search_form'] = implode($vars['search']);
}

/**
 * Override or insert variables into the comment templates.
 *
 * @param $vars
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("comment" in this case.)
 */
function acton_preprocess_comment(&$vars, $hook) {
  include_once './' . drupal_get_path('theme', 'acton') . '/template.comment.inc';
  _acton_preprocess_comment($vars, $hook);
}

/**
 * Implementation of theme_menu_item()
 */
function acton_menu_item($link, $has_children, $menu = '', $in_active_trail = FALSE, $extra_class = NULL) {
	
	$class = 'menu-item';
	
	// Add unique identifier
	static $item_id = 0;
	$item_id += 1;
	$id = 'menu-item-' . $item_id;
	
  return '<li id="'.$id.'" class="'. $class .'">'. $link . $menu ."</li>\n";
}

/**
 * Implementation of theme_menu_item_link()
 */

function acton_menu_item_link($link) {
  if (empty($link['localized_options'])) {
    $link['localized_options'] = array();
  }

	// If an item is a LOCAL TASK, render it as a tab
  if ($link['type'] & MENU_IS_LOCAL_TASK) {
    $link['title'] = '<span class="tab">' . check_plain($link['title']) . '</span>';
    $link['localized_options']['html'] = TRUE;
  }

	// Class attributes are set as localized_options
	// This is provided by anu-menu.js dynamically, but left here in case we need it in future
	// $classes = array();
  if ($link['has_children'] == '1') { 
    $classes[] = 'parent';
  }

  if (count($classes) > 0) {
    $link['localized_options']['attributes']['class'] = implode(' ', $classes);
  }
  
  // Append pagetabs-select class.
  if (($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page())) && (empty($link['localized_options']['language']))) {
    if (isset($options['attributes']['class'])) {
      $link['localized_options']['attributes']['class'] .= ' pagetabs-select';
    }
    else {
      $link['localized_options']['attributes']['class'] = 'pagetabs-select';
    }
  }
  
  return l($link['title'], $link['href'], $link['localized_options']);
}

/**
 * Implementation of theme_menu_tree()
 */ 	

function acton_menu_tree($tree) {
	// Add unique identifier
	static $item_id = 0;
	$item_id += 1;
	$id = 'nav-' . $item_id;
	
  return '<ul id="'.$id.'" class="menu">'. $tree .'</ul>';
}
/**
 * @deprecated Use drupal_html_id() instead
 *
 * Converts a string to a suitable html ID attribute.
 *
 * http://www.w3.org/TR/html4/struct/global.html#h-7.5.2 specifies what makes a
 * valid ID attribute in HTML. This function:
 *
 * - Ensure an ID starts with an alpha character by optionally adding an 'id'.
 * - Replaces any character except alphanumeric characters with dashes.
 * - Converts entire string to lowercase.
 *
 * @param $string
 *   The string
 * @return
 *   The converted string
 * @todo this doesnt do what is says on the box. ctype_lower isnt checking for a-z
 */
function acton_id_safe($string) {
  return drupal_html_id($string);
}

/**
 * Remove text from a string
 * WERE NOT USING THESE FUNCTIONS CURRENTLY
 * @param $original_string the string from which to remove $parts
 * @param $parts an array of strings to match and remove
 * @param $replace a string to replace each part with (defaults to commented out)
 * @return $new_string a new string containing original strings replaced with new ones
 */
function _acton_remove_strings($original_string, $parts, $replace = NULL){
	$new_string = $original_string;
	//$analysis_string = _acton_path_replace($original_string);
	$last_replace_was_default = 0;
	
	foreach($parts as $part){
		if(!$replace) {
			$replace = '<!-- '.$part.' -->';
			$last_replace_was_default = 1;
		}
		$new_string = str_ireplace ($part,$replace,$original_string);
		if($last_replace_was_default){
			$replace = NULL;
		}
	} 
	return $new_string;
}

function _acton_path_replace($string) {
	
	$regex = "((https?|ftp)\:\/\/)?"; // SCHEME 
	$regex .= "([a-z0-9+!*(),;?&=\$_.-]+(\:[a-z0-9+!*(),;?&=\$_.-]+)?@)?"; // User and Pass 
	$regex .= "([a-z0-9-.]*)\.([a-z]{2,3})"; // Host or IP 
	$regex .= "(\:[0-9]{2,5})?"; // Port 
	$regex .= "(\/([a-z0-9+\$_-]\.?)+)*\/?"; // Path 
	$regex .= "(\?[a-z+&\$_.-][a-z0-9;:@&%=+\/\$_.-]*)?"; // GET Query 
	$regex .= "(#[a-z_.-][a-z0-9+\$_.-]*)?"; // Anchor
	
	return preg_replace("/^$regex$/", '{path}', $string); 
}

/**
 * Extra drupal 7 html selector functions
 */

if (!function_exists('drupal_html_class')) {
  /**
   * Prepare a string for use as a valid class name.
   *
   * Do not pass one string containing multiple classes as they will be
   * incorrectly concatenated with dashes, i.e. "one two" will become "one-two".
   *
   * @param $class
   *   The class name to clean.
   * @return
   *   The cleaned class name.
   */
  function drupal_html_class($class) {
    // By default, we filter using Drupal's coding standards.
    $class = strtr(drupal_strtolower($class), array(' ' => '-', '_' => '-', '/' => '-', '[' => '-', ']' => ''));

    // http://www.w3.org/TR/CSS21/syndata.html#characters shows the syntax for valid
    // CSS identifiers (including element names, classes, and IDs in selectors.)
    //
    // Valid characters in a CSS identifier are:
    // - the hyphen (U+002D)
    // - a-z (U+0030 - U+0039)
    // - A-Z (U+0041 - U+005A)
    // - the underscore (U+005F)
    // - 0-9 (U+0061 - U+007A)
    // - ISO 10646 characters U+00A1 and higher
    // We strip out any character not in the above list.
    $class = preg_replace('/[^\x{002D}\x{0030}-\x{0039}\x{0041}-\x{005A}\x{005F}\x{0061}-\x{007A}\x{00A1}-\x{FFFF}]/u', '', $class);

    return $class;
  }
} /* End of drupal_html_class conditional definition. */

if (!function_exists('drupal_html_id')) {
  /**
   * Prepare a string for use as a valid HTML ID and guarantee uniqueness.
   *
   * @param $id
   *   The ID to clean.
   * @return
   *   The cleaned ID.
   */
  function drupal_html_id($id) {
    $id = strtr(drupal_strtolower($id), array(' ' => '-', '_' => '-', '[' => '-', ']' => ''));

    // As defined in http://www.w3.org/TR/html4/types.html#type-name, HTML IDs can
    // only contain letters, digits ([0-9]), hyphens ("-"), underscores ("_"),
    // colons (":"), and periods ("."). We strip out any character not in that
    // list. Note that the CSS spec doesn't allow colons or periods in identifiers
    // (http://www.w3.org/TR/CSS21/syndata.html#characters), so we strip those two
    // characters as well.
    $id = preg_replace('/[^A-Za-z0-9\-_]/', '', $id);

    return $id;
  }
} /* End of drupal_html_id conditional definition. */

/**
 * Returns the path to the Acton theme.
 *
 * drupal_get_filename() is broken; see #341140. When that is fixed in Drupal 6,
 * replace _acton_path() with drupal_get_path('theme', 'zen').
 */
function _acton_path() {
  static $path = FALSE;
  if (!$path) {
    $matches = drupal_system_listing('zen\.info$', 'themes', 'name', 0);
    if (!empty($matches['zen']->filename)) {
      $path = dirname($matches['zen']->filename);
    }
  }
  return $path;
}


/******************************************
 * Module compatibility functions
*******************************************/

/** 
 * Override theme_admin_menu_tree_output()
 * for compatibility with Admin module
*/
function acton_admin_menu_tree_output($tree) {
  $output = '';
  $items = array();

  // Pull out just the menu items we are going to render so that we
  // get an accurate count for the first/last classes.
  foreach ($tree as $data) {
    if (!$data['link']['hidden']) {
      $items[] = $data;
    }
  }

  $num_items = count($items);
  foreach ($items as $i => $data) {
    $extra_class = NULL;
    if ($i == 0) {
      $extra_class = 'first';
    }
    if ($i == $num_items - 1) {
      $extra_class = 'last';
    }
    $link = theme('admin_menu_item_link', $data['link']);
    $in_active_trail = isset($data['link']['in_active_trail']) ? $data['link']['in_active_trail'] : FALSE;
    if ($data['below']) {
      $output .= theme('menu_item', $link, $data['link']['has_children'], theme('admin_menu_tree_output', $data['below']), $in_active_trail, $extra_class);
    }
    else {
      $output .= theme('menu_item', $link, $data['link']['has_children'], '', $in_active_trail, $extra_class);
    }
  }

	/* Here's the hack... 
	stop it from using our new menu tree and use Drupal default */
  //return $output ? theme('menu_tree', $output) : '';
	if($output) {
		return '<ul class="menu">'. $output .'</ul>';
	}
}

/**
 * Fixes jQuery tabs
 */
function acton__tabs_alter($element){
  $element['#attributes'][] = 'pagetabs-nav'; 
}

/**
 * Fix DISPLAY SUITE tabs.
 * Theme tabs. This is based on the theme_tabset() function
 * from the tabs module. We use our own theming function because
 * otherwhise we need to loop through our fields to build the
 * right array before we an send it to theme('tabset');
 */
function acton_ds_tabs($field) {
  tabs_load();

  static $i = 1;
  $fields = $field['fields'];
  ksort($fields);

  $tab_navigation = (variable_get('tabs_navigation', 0)) ? ' tabs-navigation' : '';

  $tabs_content = '';
  $output = '<div id="tabs-'. $field['name'] .'" class="pagetabs-nav drupal-tabs js-hide'. $tab_navigation .'" style="display:block;">';
  $tabs = '<ul class="clear-block ui-tabs-nav tabs">';
  foreach ($fields as $weight => $data) {
    $tabs .= '<li class="tabset-tab-'. $i .'">
    <a href="#tabset-tab-'. $i .'"><span class="tab">'. $data['title'] .'</span></a></li>';
    $tabs_content .= '<div id="tabset-tab-'. $i .'" class="tab-content tabs-'. $field['name'] .' ui-tabs-panel '. $data['class'] .'">'. $data['content'] .'</div>';
    $i++;
  }
  $tabs .= '</ul>';
  $output .= $tabs;
  $output .= $tabs_content;
    $output .= '<span class="clear"></div>';
  $output .= '</div>';
  return $output;
}

/**
 * Implementation of theme_ds_tabs()
 *
 * @param string $content The content to render.
 * @param array $field Collection of field properties.
 */
function acton_ds_field($content, $field) {
  $output = '';

  if (!empty($content)) {
    if ($field['type'] == 'ds') {
      $output .= '<div class="field '. $field['class'] .'">';
      // Above label.
      if ($field['labelformat'] == 'above') {
        $output .= '<h3 class="field-label">'. $field['title'] .'</h3>';
      }
      // Inline label
      if ($field['labelformat'] == 'inline') {
        $output .= '<div class="field-label-inline-first">'. $field['title'] .': </div>';
      }
      $output .= $content;
      $output .= '</div>';
    }
    else {
      $output = $content;
    }
  }

  return $output;
}
