<?php
// $Id:$

/**
 * @file page.tpl.php
 *
 * Theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * Acton Variables
 * - $html: the pre-generated content from the ANU site manager
 * - $profile: the raw profile object
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $css: An array of CSS files for the current page.
 * - $directory: The directory the theme is located in, e.g. themes/garland or
 *   themes/garland/minelli.
 * - $is_front: TRUE if the current page is the front page. Used to toggle the mission statement.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Page metadata:
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $body_classes: A set of CSS classes for the BODY tag. This contains flags
 *   indicating the current layout (multiple columns, single column), the current
 *   path, whether the user is logged in, and so on.
 * - $body_classes_array: An array of the body classes. This is easier to
 *   manipulate then the string in $body_classes.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $mission: The text of the site mission, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $search_box: HTML to display the search box, empty if search has been disabled.
 * - $primary_links (array): An array containing primary navigation links for the
 *   site, if they have been configured.
 * - $secondary_links (array): An array containing secondary navigation links for
 *   the site, if they have been configured.
 *
 * Page content (in order of occurrance in the default page.tpl.php):
 * - $menubar: The HTML for the left sidebar.
 *
 * - $breadcrumb: The breadcrumb trail for the current page.
 * - $title: The page title, for use in the actual HTML content.
 * - $help: Dynamic help text, mostly for admin pages.
 * - $messages: HTML for status and error messages. Should be displayed prominently.
 * - $tabs: Tabs linking to any sub-pages beneath the current page (e.g., the view
 *   and edit tabs when displaying a node).
 * - $content: The main content of the current Drupal page.
 * - $context: The HTML for the right sidebar.
 *
 * Footer/closing data:
 * - $feed_icons: A string of all feed icons for the current page.
 * - $footer_message: The footer message as defined in the admin settings.
 * - $closure: Final closing markup from any modules that have altered the page.
 *   This variable should always be output last, after all other dynamic content.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<?php echo $html->doc_type; ?>
<head>
<?php echo $html->debug; ?>
<!-- Drupal Head -->
<?php echo $head; ?>
<!-- Drupal Styles -->
<?php echo $styles; ?>
<!-- ANU Header -->
<?php echo $html->head; ?>
<?php echo $html->meta; ?>
<!-- Drupal Scripts -->
<?php echo $scripts; ?>
<?php echo $html->js; ?>
<?php echo $html->acton_js; ?>
</head>
<body class="<?php print $body_classes; ?>">
  <?php if ($html->alert_bar): ?>
    <?php print $html->alert_bar; ?>
  <?php endif; ?>
  <?php echo $html->banner; ?>
  
  <?php if ($left || $profile->settings->show_search) { ?>
    <!-- START SIDEBAR -->
    <!--noindex-->
    <div id="menu" class="<?php print $region_classes['sidebar']; ?>">
      <div class="narrow">
        <?php if($html->search_box) { echo $html->search_box; }?>
          <?php print $left; ?>
        <?php if ($feed_icons): ?>
            <div class="feed-icons"><?php print $feed_icons; ?></div>
          <?php endif; ?>
        </div>
    </div> 
    <!--endnoindex-->
    <!-- END SIDEBAR -->
  <?php }; ?>

  <!-- START PAGE CONTENT -->
  <div id="content" class="margintop">
    
    <?php if(isset($feature) && $is_front){ ?>
      <?php print $feature; ?>
    <?php }; ?>

    <?php if ($breadcrumb || $title || $help || $messages): ?>
      <div id="content-header" class="doublewide nopadtop nopadbottom">
        <?php print $messages; ?>
        <?php if($status == 'unpublished') { echo '<div class="status unpublished">This node is unpublished.</div>'; }?>
        <?php if($breadcrumb){ ?>
          <div id="breadcrumb">
            <?php print $breadcrumb.$breadcrumb_title; ?>
          </div>
        <?php }?>
        
        <?php if ($title): ?>
            <h1 class="title"><?php print $title; ?></h1>
        <?php endif; ?>
  
        <?php print $help; ?>
      </div> <!-- /#content-header -->
    <?php endif; ?>
  
    <?php if ($content_top): ?>
      <div id="content-top" class="<?php print $region_classes['content_top']; ?>">
        <?php print $content_top; ?>
      </div> <!-- /#content-top -->
    <?php endif; ?>

    <?php if ($tabs): ?>
      <div class="tabs doublewide"><?php print $tabs; ?></div>
    <?php endif; ?>
    
    <?php if($palette){ ?>
      <div id="palette"><?php print $palette ?></div>
    <?php }?>
    
    
    <?php if ($content && $right): ?>
      <div id="content-area" class="<?php print $region_classes['content']; ?>">
        <?php print $content; ?>
      </div>
      <div id="content-area" class="<?php print $region_classes['right']; ?>">
        <?php print $right; ?>
      </div>
    <?php elseif ($content && !$right): ?>
      <div id="content-area" class="<?php print $region_classes['content']; ?>">
        <?php print $content; ?>
      </div>
    <?php endif; ?>


    <?php if ($content_bottom): ?>
      <div id="content-bottom" class="<?php print $region_classes['content_bottom']; ?>">
        <?php print $content_bottom; ?>
      </div>
    <?php endif; ?>
  </div>
  <!-- END MAIN PAGE CONTENT -->

  <?php 
  echo $html->update; 
  echo $html->footer;
  ?>
  <?php if ($closure_region): ?>
    <div id="closure-blocks" class="region region-closure">
      <?php print $closure_region; ?>
    </div>
  <?php endif; ?>

  <?php print $closure; ?>
  <?php print $html->footer_js; ?>
</body>
</html>