<?php
// $Id:$

// Include the definition of acton_theme_get_default_settings().
include_once './' . drupal_get_path('theme', 'acton') . '/template.theme-registry.inc';


/**
 * Implementation of THEMEHOOK_settings() function.
 *
 * @param $saved_settings
 *   An array of saved settings for this theme.
 * @param $subtheme_defaults
 *   Allow a subtheme to override the default values.
 * @return
 *   A form array.
 */
function acton_settings($saved_settings, $subtheme_defaults = array()) {

  // Add the form's CSS
  drupal_add_css(drupal_get_path('theme', 'acton') . '/theme-settings.css', 'theme');

  // Add javascript to show/hide optional settings
  drupal_add_js(drupal_get_path('theme', 'acton') . '/theme-settings.js', 'theme');

  // Get the default values from the .info file.
  $defaults = acton_theme_get_default_settings('acton');

  // Allow a subtheme to override the default values.
  $defaults = array_merge($defaults, $subtheme_defaults);

  // Merge the saved variables and their default values.
  $settings = array_merge($defaults, $saved_settings);

  /*
   * Create the form using Forms API
   */
  $form['acton-div-opening'] = array(
    '#value'         => '<div id="acton-settings">',
  );

  $form['acton_block_editing'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Show block editing on hover'),
    '#description'   => t('When hovering over a block, privileged users will see block editing links.'),
    '#default_value' => $settings['acton_block_editing'],
  );
  
  $form['anu_styles'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('ANU styles settings'),
    '#attributes'    => array('id' => 'acton-anu-styles'),
  );
  
  $form['anu_styles']['acton_menu_colour'] = array(
    '#type'          => 'select',
    '#title'         => t('Secondary menu colour'),
    '#description'   => t('Secondary menus can be the default site colour or grey, and if you are using a College colour instead of Platinum, they can also be Platinum.'),
    '#default_value' => $settings['acton_menu_colour'],
    '#options'       => array(
                          'main'  => t('College or Platinum'),
                          'uni'  => t('Platinum'),
                          'grey'  => t('Grey'),
                        ),
  );
  $form['breadcrumb'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Breadcrumb settings'),
    '#attributes'    => array('id' => 'acton-breadcrumb'),
  );
  $form['breadcrumb']['acton_breadcrumb'] = array(
    '#type'          => 'select',
    '#title'         => t('Display breadcrumb'),
    '#default_value' => $settings['acton_breadcrumb'],
    '#options'       => array(
                          'yes'   => t('Yes'),
                          'admin' => t('Only in admin section'),
                          'no'    => t('No'),
                        ),
  );
  $form['breadcrumb']['acton_breadcrumb_sitename'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Breadcrumb site name'),
    '#description'   => t('Site name to display instead of "Home", in the breadcrumb. Text only.'),
    '#default_value' => $settings['acton_breadcrumb_sitename'],
    '#size'          => 40,
    '#maxlength'     => 40,
    '#prefix'        => '<div id="div-acton-breadcrumb-collapse">', // jquery hook to show/hide optional widgets
    '#suffix'        => '</div>',
  );
  
  $form['developer'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Developer settings'),
    '#attributes'    => array('id' => 'acton-developer'),
  );
  $form['developer']['acton_rebuild_registry'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Rebuild theme registry on every page.'),
    '#default_value' => $settings['acton_rebuild_registry'],
    '#description'   => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    '#prefix'        => '<div id="div-acton-registry"><strong>' . t('Theme registry:') . '</strong>',
    '#suffix'        => '</div>',
  );
  $form['acton-div-closing'] = array(
    '#value'         => '</div>',
  );

  // Return the form
  return $form;
}
